@@ -127,6 +127,8 @@ var roy = {
                 graph_data['time_limit'] = graph.time_limit;
                 graph_data['y_scale_type'] = graph.y_scale_type;
                 graph_data['parameter_types'] = graph.parameter_types;
+                graph_data['width'] = graph.w;
+                graph_data['height'] = graph.h;
                 json_data['graphs'].push(graph_data);
                 console.log("Saving " + graph.type);
             });
